pyxmpp.presence

Package pyxmpp :: Module presence |
[hide private]

# Module presence

source code

Presence XMPP stanza handling

Normative reference:
  - RFC 3920

Classes | [hide private]
| Presence Wraper object for <presence /> stanzas.

Variables | [hide private]
| __revision__ = ``'``$Id: presence.py 714 2010-04-05 10:20:10Z jajc``...``
| presence_types = ``(``'``available``'``,` `'``unavailable``'``,` `'``probe``'``,` `'``subscr``...``
| accept_responses = ``{``'``subscribe``'``:` `'``subscribed``'``,` `'``subscribed``'``:` `'``...``
| deny_responses = ``{``'``subscribe``'``:` `'``unsubscribed``'``,` `'``subscribed``'``:` `'``...``
| __package__ = ``'``pyxmpp``'``

Imports: libxml2, to_utf8, from_utf8, Stanza, common_ns

Variables Details | [hide private]

  ### __revision__ Value:
      '$Id: presence.py 714 2010-04-05 10:20:10Z jajcus $'

  ### presence_types Value:
      ('available',
       'unavailable',
       'probe',
       'subscribe',
       'unsubscribe',
       'subscribed',
       'unsubscribed',
       'invisible',
      ...

  ### accept_responses Value:
      {'subscribe': 'subscribed',
       'subscribed': 'subscribe',
       'unsubscribe': 'unsubscribed',
       'unsubscribed': 'unsubscribe'}

  ### deny_responses Value:
      {'subscribe': 'unsubscribed',
       'subscribed': 'unsubscribe',
       'unsubscribe': 'subscribed',
       'unsubscribed': 'subscribe'}